@@ -42,7 +42,6 @@
 #include <string.h>
 #include <stdlib.h>
 #include <glib/gi18n.h>
-#include <gconf/gconf-client.h>
 
 #if HAVE_EXEMPI
 #include <exempi/xmp.h>
@@ -186,6 +185,8 @@ main (int argc, char **argv)
 	GError *error = NULL;
 	GOptionContext *ctx;
 
+	g_setenv ("GSETTINGS_BACKEND", "gconf", FALSE);
+
 	if (!g_thread_supported ())
 		g_thread_init (NULL);
 
